@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- Mode: python; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
 #
 # This program is free software; you can redistribute it and/or modify it under
@@ -147,42 +146,23 @@ class FieldResult(Field):
             '    QmiMessage *self,\n'
             '    const gchar *line_prefix)\n'
             '{\n'
-            '    const guint8 *buffer;\n'
-            '    guint16 buffer_len;\n'
+            '    gsize offset = 0;\n'
+            '    gsize init_offset;\n'
+            '    guint16 error_status;\n'
+            '    guint16 error_code;\n'
             '\n'
-            '    buffer = qmi_message_get_raw_tlv (self,\n'
-            '                                      ${tlv_id},\n'
-            '                                      &buffer_len);\n'
-            '    if (buffer) {\n'
-            '        GString *printable;\n'
-            '        guint16 error_status;\n'
-            '        guint16 error_code;\n'
+            '    if ((init_offset = qmi_message_tlv_read_init (self, ${tlv_id}, NULL, NULL)) == 0)\n'
+            '        return NULL;\n'
+            '    if (!qmi_message_tlv_read_guint16 (self, init_offset, &offset, QMI_ENDIAN_LITTLE, &error_status, NULL))\n'
+            '        return NULL;\n'
+            '    if (!qmi_message_tlv_read_guint16 (self, init_offset, &offset, QMI_ENDIAN_LITTLE, &error_code, NULL))\n'
+            '        return NULL;\n'
+            '    g_warn_if_fail (__qmi_message_tlv_read_remaining_size (self, init_offset, offset) == 0);\n'
             '\n'
-            '        printable = g_string_new ("");\n'
-            '        qmi_utils_read_guint16_from_buffer (\n'
-            '            &buffer,\n'
-            '            &buffer_len,\n'
-            '            QMI_ENDIAN_LITTLE,\n'
-            '            &error_status);\n'
-            '        qmi_utils_read_guint16_from_buffer (\n'
-            '            &buffer,\n'
-            '            &buffer_len,\n'
-            '            QMI_ENDIAN_LITTLE,\n'
-            '            &error_code);\n'
+            '    if (error_status == QMI_STATUS_SUCCESS)\n'
+            '        return g_strdup ("SUCCESS");\n'
             '\n'
-            '        g_warn_if_fail (buffer_len == 0);\n'
-            '\n'
-            '        if (error_status == QMI_STATUS_SUCCESS)\n'
-            '            g_string_append (printable, "SUCCESS");\n'
-            '        else\n'
-            '            g_string_append_printf (printable,\n'
-            '                                    "FAILURE: %s",\n'
-            '                                    qmi_protocol_error_get_string ((QmiProtocolError) error_code));\n'
-            '\n'
-            '        return g_string_free (printable, FALSE);\n'
-            '    }\n'
-            '\n'
-            '    return NULL;\n'
+            '    return g_strdup_printf ("FAILURE: %s", qmi_protocol_error_get_string ((QmiProtocolError) error_code));\n'
             '}\n')
         f.write(string.Template(template).substitute(translations))
 
