@@ -74,6 +74,13 @@
 #include "qmi-enums-voice.h"
 #include "qmi-voice.h"
 
+#include "qmi-flags64-loc.h"
+#include "qmi-enums-loc.h"
+#include "qmi-loc.h"
+
+#include "qmi-enums-qos.h"
+#include "qmi-qos.h"
+
 /* generated */
 #include "qmi-error-types.h"
 #include "qmi-enum-types.h"
