@@ -104,6 +104,15 @@ typedef struct _QmiDevicePrivate QmiDevicePrivate;
  */
 #define QMI_DEVICE_SIGNAL_INDICATION "indication"
 
+/**
+ * QMI_DEVICE_REMOVED:
+ *
+ * Symbol defining the #QmiDevice::device-removed signal.
+ *
+ * Since: 1.20
+ */
+#define QMI_DEVICE_SIGNAL_REMOVED "device-removed"
+
 /**
  * QmiDevice:
  *
@@ -243,22 +252,24 @@ gboolean qmi_device_is_open (QmiDevice *self);
  * @QMI_DEVICE_OPEN_FLAGS_PROXY: Try to open the port through the 'qmi-proxy'. Since: 1.8.
  * @QMI_DEVICE_OPEN_FLAGS_MBIM: open an MBIM port with QMUX tunneling service. Since: 1.16.
  * @QMI_DEVICE_OPEN_FLAGS_AUTO: open a port either in QMI or MBIM mode, depending on device driver. Since: 1.18.
+ * @QMI_DEVICE_OPEN_FLAGS_EXPECT_INDICATIONS: Explicitly state that indications are wanted (implicit in QMI mode, optional when in MBIM mode).
  *
  * Flags to specify which actions to be performed when the device is open.
  *
  * Since: 1.0
  */
 typedef enum {
-    QMI_DEVICE_OPEN_FLAGS_NONE              = 0,
-    QMI_DEVICE_OPEN_FLAGS_VERSION_INFO      = 1 << 0,
-    QMI_DEVICE_OPEN_FLAGS_SYNC              = 1 << 1,
-    QMI_DEVICE_OPEN_FLAGS_NET_802_3         = 1 << 2,
-    QMI_DEVICE_OPEN_FLAGS_NET_RAW_IP        = 1 << 3,
-    QMI_DEVICE_OPEN_FLAGS_NET_QOS_HEADER    = 1 << 4,
-    QMI_DEVICE_OPEN_FLAGS_NET_NO_QOS_HEADER = 1 << 5,
-    QMI_DEVICE_OPEN_FLAGS_PROXY             = 1 << 6,
-    QMI_DEVICE_OPEN_FLAGS_MBIM              = 1 << 7,
-    QMI_DEVICE_OPEN_FLAGS_AUTO              = 1 << 8,
+    QMI_DEVICE_OPEN_FLAGS_NONE               = 0,
+    QMI_DEVICE_OPEN_FLAGS_VERSION_INFO       = 1 << 0,
+    QMI_DEVICE_OPEN_FLAGS_SYNC               = 1 << 1,
+    QMI_DEVICE_OPEN_FLAGS_NET_802_3          = 1 << 2,
+    QMI_DEVICE_OPEN_FLAGS_NET_RAW_IP         = 1 << 3,
+    QMI_DEVICE_OPEN_FLAGS_NET_QOS_HEADER     = 1 << 4,
+    QMI_DEVICE_OPEN_FLAGS_NET_NO_QOS_HEADER  = 1 << 5,
+    QMI_DEVICE_OPEN_FLAGS_PROXY              = 1 << 6,
+    QMI_DEVICE_OPEN_FLAGS_MBIM               = 1 << 7,
+    QMI_DEVICE_OPEN_FLAGS_AUTO               = 1 << 8,
+    QMI_DEVICE_OPEN_FLAGS_EXPECT_INDICATIONS = 1 << 9,
 } QmiDeviceOpenFlags;
 
 /**
@@ -306,28 +317,6 @@ gboolean qmi_device_open_finish (QmiDevice     *self,
                                  GAsyncResult  *res,
                                  GError       **error);
 
-/**
- * qmi_device_close:
- * @self: a #QmiDevice
- * @error: Return location for error or %NULL.
- *
- * Synchronously closes a #QmiDevice, preventing any further I/O.
- *
- * If this device was opened with @QMI_DEVICE_OPEN_FLAGS_MBIM, this
- * operation will not wait for the response of the underlying MBIM
- * close sequence.
- *
- * Closing a #QmiDevice multiple times will not return an error.
- *
- * Returns: %TRUE if successful, %FALSE if @error is set.
- *
- * Since: 1.0
- * Deprecated: 1.18: Use qmi_device_close_async() instead.
- */
-G_DEPRECATED
-gboolean qmi_device_close (QmiDevice  *self,
-                           GError    **error);
-
 /**
  * qmi_device_close_async:
  * @self: a #QmiDevice.
