@@ -134,8 +134,14 @@ typedef enum {
  * @QMI_NAS_ACTIVE_BAND_EUTRAN_19: EUTRAN band 19.
  * @QMI_NAS_ACTIVE_BAND_EUTRAN_20: EUTRAN band 20.
  * @QMI_NAS_ACTIVE_BAND_EUTRAN_21: EUTRAN band 21.
+ * @QMI_NAS_ACTIVE_BAND_EUTRAN_23: EUTRAN band 23.
  * @QMI_NAS_ACTIVE_BAND_EUTRAN_24: EUTRAN band 24.
  * @QMI_NAS_ACTIVE_BAND_EUTRAN_25: EUTRAN band 25.
+ * @QMI_NAS_ACTIVE_BAND_EUTRAN_26: EUTRAN band 26.
+ * @QMI_NAS_ACTIVE_BAND_EUTRAN_28: EUTRAN band 28.
+ * @QMI_NAS_ACTIVE_BAND_EUTRAN_29: EUTRAN band 29.
+ * @QMI_NAS_ACTIVE_BAND_EUTRAN_30: EUTRAN band 30.
+ * @QMI_NAS_ACTIVE_BAND_EUTRAN_32: EUTRAN band 32.
  * @QMI_NAS_ACTIVE_BAND_EUTRAN_33: EUTRAN band 33.
  * @QMI_NAS_ACTIVE_BAND_EUTRAN_34: EUTRAN band 34.
  * @QMI_NAS_ACTIVE_BAND_EUTRAN_35: EUTRAN band 35.
@@ -147,6 +153,12 @@ typedef enum {
  * @QMI_NAS_ACTIVE_BAND_EUTRAN_41: EUTRAN band 41.
  * @QMI_NAS_ACTIVE_BAND_EUTRAN_42: EUTRAN band 42.
  * @QMI_NAS_ACTIVE_BAND_EUTRAN_43: EUTRAN band 43.
+ * @QMI_NAS_ACTIVE_BAND_EUTRAN_46: EUTRAN band 46.
+ * @QMI_NAS_ACTIVE_BAND_EUTRAN_66: EUTRAN band 66.
+ * @QMI_NAS_ACTIVE_BAND_EUTRAN_125: EUTRAN band 125.
+ * @QMI_NAS_ACTIVE_BAND_EUTRAN_126: EUTRAN band 126.
+ * @QMI_NAS_ACTIVE_BAND_EUTRAN_127: EUTRAN band 127.
+ * @QMI_NAS_ACTIVE_BAND_EUTRAN_250: EUTRAN band 250.
  * @QMI_NAS_ACTIVE_BAND_TDSCDMA_A: TD-SCDMA Band A.
  * @QMI_NAS_ACTIVE_BAND_TDSCDMA_B: TD-SCDMA Band B.
  * @QMI_NAS_ACTIVE_BAND_TDSCDMA_C: TD-SCDMA Band C.
@@ -218,8 +230,14 @@ typedef enum {
     QMI_NAS_ACTIVE_BAND_EUTRAN_19 = 144,
     QMI_NAS_ACTIVE_BAND_EUTRAN_20 = 145,
     QMI_NAS_ACTIVE_BAND_EUTRAN_21 = 146,
+    QMI_NAS_ACTIVE_BAND_EUTRAN_23 = 152,
     QMI_NAS_ACTIVE_BAND_EUTRAN_24 = 147,
     QMI_NAS_ACTIVE_BAND_EUTRAN_25 = 148,
+    QMI_NAS_ACTIVE_BAND_EUTRAN_26 = 153,
+    QMI_NAS_ACTIVE_BAND_EUTRAN_28 = 158,
+    QMI_NAS_ACTIVE_BAND_EUTRAN_29 = 159,
+    QMI_NAS_ACTIVE_BAND_EUTRAN_30 = 160,
+    QMI_NAS_ACTIVE_BAND_EUTRAN_32 = 154,
     QMI_NAS_ACTIVE_BAND_EUTRAN_33 = 135,
     QMI_NAS_ACTIVE_BAND_EUTRAN_34 = 136,
     QMI_NAS_ACTIVE_BAND_EUTRAN_35 = 137,
@@ -231,6 +249,12 @@ typedef enum {
     QMI_NAS_ACTIVE_BAND_EUTRAN_41 = 149,
     QMI_NAS_ACTIVE_BAND_EUTRAN_42 = 150,
     QMI_NAS_ACTIVE_BAND_EUTRAN_43 = 151,
+    QMI_NAS_ACTIVE_BAND_EUTRAN_46 = 163,
+    QMI_NAS_ACTIVE_BAND_EUTRAN_66 = 161,
+    QMI_NAS_ACTIVE_BAND_EUTRAN_125 = 155,
+    QMI_NAS_ACTIVE_BAND_EUTRAN_126 = 156,
+    QMI_NAS_ACTIVE_BAND_EUTRAN_127 = 157,
+    QMI_NAS_ACTIVE_BAND_EUTRAN_250 = 162,
     QMI_NAS_ACTIVE_BAND_TDSCDMA_A = 200,
     QMI_NAS_ACTIVE_BAND_TDSCDMA_B = 201,
     QMI_NAS_ACTIVE_BAND_TDSCDMA_C = 202,
@@ -424,6 +448,29 @@ typedef enum {
  * Since: 1.0
  */
 
+/*****************************************************************************/
+/* Helper enums for the 'QMI NAS Attach Detach' request/response */
+
+/**
+ * QmiNasPsAttachAction:
+ * @QMI_NAS_PS_ATTACH_ACTION_ATTACH: Attach the PS domain.
+ * @QMI_NAS_PS_ATTACH_ACTION_DETACH: Detach the PS domain.
+ *
+ * Packet Switched domain attach/detach action.
+ *
+ * Since: 1.20
+ */
+typedef enum {
+    QMI_NAS_PS_ATTACH_ACTION_ATTACH = 0x01,
+    QMI_NAS_PS_ATTACH_ACTION_DETACH = 0x02
+} QmiNasPsAttachAction;
+
+/**
+ * qmi_nas_ps_attach_action_get_string:
+ *
+ * Since: 1.20
+ */
+
 /*****************************************************************************/
 /* Helper enums for the 'QMI NAS Get Serving System' request/response */
 
