@@ -19,7 +19,7 @@
  *
  * Copyright (C) 2012 Lanedo GmbH.
  * Copyright (C) 2012 Google, Inc.
-
+ * Copyright (C) 2012-2017 Aleksander Morgado <aleksander@aleksander.es>
  */
 
 #ifndef _LIBQMI_GLIB_QMI_FLAGS64_DMS_H_
@@ -126,6 +126,12 @@ typedef enum {
     /* Bits 62-63 reserved */
 } QmiDmsBandCapability;
 
+/**
+ * qmi_dms_band_capability_build_string_from_mask:
+ *
+ * Since: 1.0
+ */
+
 /**
  * QmiDmsLteBandCapability:
  * @QMI_DMS_LTE_BAND_CAPABILITY_EUTRAN_1: LTE EUTRAN Band 1
@@ -149,6 +155,13 @@ typedef enum {
  * @QMI_DMS_LTE_BAND_CAPABILITY_EUTRAN_21: LTE EUTRAN Band 21.
  * @QMI_DMS_LTE_BAND_CAPABILITY_EUTRAN_24: LTE EUTRAN Band 24.
  * @QMI_DMS_LTE_BAND_CAPABILITY_EUTRAN_25: LTE EUTRAN Band 25.
+ * @QMI_DMS_LTE_BAND_CAPABILITY_EUTRAN_26: LTE EUTRAN Band 26.
+ * @QMI_DMS_LTE_BAND_CAPABILITY_EUTRAN_27: LTE EUTRAN Band 27.
+ * @QMI_DMS_LTE_BAND_CAPABILITY_EUTRAN_28: LTE EUTRAN Band 28.
+ * @QMI_DMS_LTE_BAND_CAPABILITY_EUTRAN_29: LTE EUTRAN Band 29.
+ * @QMI_DMS_LTE_BAND_CAPABILITY_EUTRAN_30: LTE EUTRAN Band 30.
+ * @QMI_DMS_LTE_BAND_CAPABILITY_EUTRAN_31: LTE EUTRAN Band 31.
+ * @QMI_DMS_LTE_BAND_CAPABILITY_EUTRAN_32: LTE EUTRAN Band 32.
  * @QMI_DMS_LTE_BAND_CAPABILITY_EUTRAN_33: LTE EUTRAN Band 33.
  * @QMI_DMS_LTE_BAND_CAPABILITY_EUTRAN_34: LTE EUTRAN Band 34.
  * @QMI_DMS_LTE_BAND_CAPABILITY_EUTRAN_35: LTE EUTRAN Band 35.
@@ -187,7 +200,13 @@ typedef enum {
     /* Bit 21-22 reserved */
     QMI_DMS_LTE_BAND_CAPABILITY_EUTRAN_24 = 1 << 23,
     QMI_DMS_LTE_BAND_CAPABILITY_EUTRAN_25 = 1 << 24,
-    /* Bit 25-31 reserved */
+    QMI_DMS_LTE_BAND_CAPABILITY_EUTRAN_26 = 1 << 25,
+    QMI_DMS_LTE_BAND_CAPABILITY_EUTRAN_27 = 1 << 26,
+    QMI_DMS_LTE_BAND_CAPABILITY_EUTRAN_28 = 1 << 27,
+    QMI_DMS_LTE_BAND_CAPABILITY_EUTRAN_29 = 1 << 28,
+    QMI_DMS_LTE_BAND_CAPABILITY_EUTRAN_30 = 1 << 29,
+    QMI_DMS_LTE_BAND_CAPABILITY_EUTRAN_31 = 1 << 30,
+    QMI_DMS_LTE_BAND_CAPABILITY_EUTRAN_32 = 1 << 31,
     QMI_DMS_LTE_BAND_CAPABILITY_EUTRAN_33 = ((guint64) 1) << 32,
     QMI_DMS_LTE_BAND_CAPABILITY_EUTRAN_34 = ((guint64) 1) << 33,
     QMI_DMS_LTE_BAND_CAPABILITY_EUTRAN_35 = ((guint64) 1) << 34,
@@ -202,4 +221,10 @@ typedef enum {
     /* Bit 43-64 reserved */
 } QmiDmsLteBandCapability;
 
+/**
+ * qmi_dms_lte_band_capability_build_string_from_mask:
+ *
+ * Since: 1.0
+ */
+
 #endif /* _LIBQMI_GLIB_QMI_FLAGS64_DMS_H_ */
