@@ -53,6 +53,7 @@
 #include "qmi-wda.h"
 #include "qmi-voice.h"
 #include "qmi-loc.h"
+#include "qmi-qos.h"
 
 #define PACKED __attribute__((packed))
 
@@ -460,6 +461,9 @@ qmi_message_response_new (QmiMessage       *request,
                                 qmi_message_get_transaction_id (request),
                                 qmi_message_get_message_id (request));
 
+    /* Set sender type flag */
+    ((struct full_message *)(((GByteArray *)response)->data))->qmux.flags = 0x80;
+
     /* Set the response flag */
     if (message_is_control (request))
         ((struct full_message *)(((GByteArray *)response)->data))->qmi.control.header.flags |= QMI_CTL_FLAG_RESPONSE;
@@ -582,15 +586,9 @@ qmi_message_tlv_write_complete (QmiMessage  *self,
     g_return_val_if_fail (self != NULL, FALSE);
     g_return_val_if_fail (self->len >= (tlv_offset + sizeof (struct tlv)), FALSE);
 
+    /* A TLV without content is actually not an error, e.g. TLV strings with no
+     * data are totally valid. */
     tlv_length = self->len - tlv_offset;
-    if (tlv_length == sizeof (struct tlv)) {
-        g_set_error (error,
-                     QMI_CORE_ERROR,
-                     QMI_CORE_ERROR_TLV_EMPTY,
-                     "Empty TLV, no value set");
-        g_byte_array_set_size (self, tlv_offset);
-        return FALSE;
-    }
 
     /* Update length fields. */
     tlv = tlv_get_header (self, tlv_offset);
@@ -870,11 +868,6 @@ qmi_message_tlv_read_init (QmiMessage  *self,
     }
 
     tlv_length = GUINT16_FROM_LE (tlv->length);
-    if (!tlv_length) {
-        g_set_error (error, QMI_CORE_ERROR, QMI_CORE_ERROR_TLV_EMPTY,
-                     "TLV 0x%02X is empty", type);
-        return 0;
-    }
 
     if (((guint8 *) tlv_next (tlv)) > ((guint8 *) qmi_end (self))) {
         g_set_error (error, QMI_CORE_ERROR, QMI_CORE_ERROR_TLV_TOO_LONG,
@@ -1152,11 +1145,12 @@ qmi_message_tlv_read_sized_guint (QmiMessage  *self,
 }
 
 gboolean
-qmi_message_tlv_read_gfloat (QmiMessage  *self,
-                             gsize        tlv_offset,
-                             gsize       *offset,
-                             gfloat      *out,
-                             GError     **error)
+qmi_message_tlv_read_gfloat_endian (QmiMessage  *self,
+                                    gsize        tlv_offset,
+                                    gsize       *offset,
+                                    QmiEndian    endian,
+                                    gfloat      *out,
+                                    GError     **error)
 {
     const guint8 *ptr;
 
@@ -1167,12 +1161,42 @@ qmi_message_tlv_read_gfloat (QmiMessage  *self,
     if (!(ptr = tlv_error_if_read_overflow (self, tlv_offset, *offset, 4, error)))
         return FALSE;
 
-    /* Yeah, do this for now */
     memcpy (out, ptr, 4);
+    if (endian == QMI_ENDIAN_BIG)
+        *out = __QMI_GFLOAT_FROM_BE (*out);
+    else
+        *out = __QMI_GFLOAT_FROM_LE (*out);
     *offset = *offset + 4;
     return TRUE;
 }
 
+gboolean
+qmi_message_tlv_read_gdouble (QmiMessage  *self,
+                              gsize        tlv_offset,
+                              gsize       *offset,
+                              QmiEndian    endian,
+                              gdouble     *out,
+                              GError     **error)
+{
+    const guint8 *ptr;
+
+    g_return_val_if_fail (self != NULL, FALSE);
+    g_return_val_if_fail (offset != NULL, FALSE);
+    g_return_val_if_fail (out != NULL, FALSE);
+
+    if (!(ptr = tlv_error_if_read_overflow (self, tlv_offset, *offset, 8, error)))
+        return FALSE;
+
+    /* Yeah, do this for now */
+    memcpy (out, ptr, 8);
+    if (endian == QMI_ENDIAN_BIG)
+        *out = __QMI_GDOUBLE_FROM_BE (*out);
+    else
+        *out = __QMI_GDOUBLE_FROM_LE (*out);
+    *offset = *offset + 8;
+    return TRUE;
+}
+
 gboolean
 qmi_message_tlv_read_string (QmiMessage  *self,
                              gsize        tlv_offset,
@@ -1543,6 +1567,9 @@ qmi_message_get_printable_full (QmiMessage        *self,
     case QMI_SERVICE_LOC:
         contents = __qmi_message_loc_get_printable (self, context, line_prefix);
         break;
+    case QMI_SERVICE_QOS:
+        contents = __qmi_message_qos_get_printable (self, context, line_prefix);
+        break;
     default:
         break;
     }
@@ -1555,13 +1582,6 @@ qmi_message_get_printable_full (QmiMessage        *self,
     return g_string_free (printable, FALSE);
 }
 
-gchar *
-qmi_message_get_printable (QmiMessage  *self,
-                           const gchar *line_prefix)
-{
-    return qmi_message_get_printable_full (self, NULL, line_prefix);
-}
-
 gboolean
 qmi_message_get_version_introduced_full (QmiMessage        *self,
                                          QmiMessageContext *context,
@@ -1610,11 +1630,3 @@ qmi_message_get_version_introduced_full (QmiMessage        *self,
         return FALSE;
     }
 }
-
-gboolean
-qmi_message_get_version_introduced (QmiMessage *self,
-                                    guint      *major,
-                                    guint      *minor)
-{
-    return qmi_message_get_version_introduced_full (self, NULL, major, minor);
-}
