@@ -103,7 +103,7 @@ test_message_parse_common (const guint8 *buffer,
             break;
         }
 
-        printable = qmi_message_get_printable (message, "");
+        printable = qmi_message_get_printable_full (message, NULL, "");
 #ifdef TEST_PRINT_MESSAGE
         g_print ("\n%s\n", printable);
 #endif
@@ -189,7 +189,7 @@ test_message_overflow_common (const guint8 *buffer,
     g_assert_no_error (error);
     g_assert (message);
 
-    printable = qmi_message_get_printable (message, "");
+    printable = qmi_message_get_printable_full (message, NULL, "");
     g_print ("\n%s\n", printable);
     g_assert (strstr (printable, "ERROR: Reading TLV would overflow"));
     g_free (printable);
@@ -278,7 +278,7 @@ test_message_new_response_ok (void)
     static const guint8 expected_buffer [] = {
         0x01,       /* marker */
         0x13, 0x00, /* qmux length */
-        0x00,       /* qmux flags */
+        0x80,       /* qmux flags */
         0x02,       /* service: DMS */
         0x01,       /* client id */
         0x02,       /* service flags */
@@ -320,7 +320,7 @@ test_message_new_response_error (void)
     static const guint8 expected_buffer [] = {
         0x01,       /* marker */
         0x13, 0x00, /* qmux length */
-        0x00,       /* qmux flags */
+        0x80,       /* qmux flags */
         0x02,       /* service: DMS */
         0x01,       /* client id */
         0x02,       /* service flags */
@@ -373,8 +373,8 @@ test_message_tlv_write_empty (void)
     g_assert (init_offset > 0);
 
     ret = qmi_message_tlv_write_complete (self, init_offset, &error);
-    g_assert_error (error, QMI_CORE_ERROR, QMI_CORE_ERROR_TLV_EMPTY);
-    g_assert (!ret);
+    g_assert_no_error (error);
+    g_assert (ret);
 
     qmi_message_unref (self);
 }
