@@ -38,8 +38,9 @@ gboolean qmicli_read_uim_pin_id_from_string                  (const gchar *str,
                                                               QmiUimPinId *out);
 gboolean qmicli_read_operating_mode_from_string              (const gchar *str,
                                                               QmiDmsOperatingMode *out);
-gboolean qmicli_read_rat_mode_pref_from_string               (const gchar *str,
-                                                              QmiNasRatModePreference *out);
+gboolean qmicli_read_ssp_options_from_string                 (const gchar              *str,
+                                                              QmiNasRatModePreference  *out_mode_preference,
+                                                              GArray                  **out_acquisition_order);
 gboolean qmicli_read_facility_from_string                    (const gchar *str,
                                                               QmiDmsUimFacility *out);
 gboolean qmicli_read_enable_disable_from_string              (const gchar *str,
@@ -69,6 +70,8 @@ gboolean qmicli_read_autoconnect_setting_roaming_from_string (const gchar *str,
                                                               QmiWdsAutoconnectSettingRoaming *out);
 gboolean qmicli_read_authentication_from_string              (const gchar *str,
                                                               QmiWdsAuthentication *out);
+gboolean qmicli_read_pdp_type_from_string                    (const gchar *str,
+                                                              QmiWdsPdpType *out);
 gboolean qmicli_read_boot_image_download_mode_from_string    (const gchar *str,
                                                               QmiDmsBootImageDownloadMode *out);
 gboolean qmicli_read_hp_device_mode_from_string              (const gchar *str,
