@@ -198,6 +198,9 @@ set_pin_protection_input_create (const gchar *str)
         qmicli_read_enable_disable_from_string (split[1], &enable_disable) &&
         qmicli_read_non_empty_string (split[2], "current PIN", &current_pin)) {
         GError *error = NULL;
+        GArray *dummy_aid;
+
+        dummy_aid = g_array_new (FALSE, FALSE, sizeof (guint8));
 
         input = qmi_message_uim_set_pin_protection_input_new ();
         if (!qmi_message_uim_set_pin_protection_input_set_info (
@@ -206,10 +209,10 @@ set_pin_protection_input_create (const gchar *str)
                 enable_disable,
                 current_pin,
                 &error) ||
-            !qmi_message_uim_set_pin_protection_input_set_session_information (
+            !qmi_message_uim_set_pin_protection_input_set_session (
                 input,
                 QMI_UIM_SESSION_TYPE_CARD_SLOT_1,
-                "", /* ignored */
+                dummy_aid, /* ignored */
                 &error)) {
             g_printerr ("error: couldn't create input data bundle: '%s'\n",
                         error->message);
@@ -217,6 +220,7 @@ set_pin_protection_input_create (const gchar *str)
             qmi_message_uim_set_pin_protection_input_unref (input);
             input = NULL;
         }
+        g_array_unref (dummy_aid);
     }
     g_strfreev (split);
 
@@ -286,6 +290,9 @@ verify_pin_input_create (const gchar *str)
     if (qmicli_read_uim_pin_id_from_string (split[0], &pin_id) &&
         qmicli_read_non_empty_string (split[1], "current PIN", &current_pin)) {
         GError *error = NULL;
+        GArray *dummy_aid;
+
+        dummy_aid = g_array_new (FALSE, FALSE, sizeof (guint8));
 
         input = qmi_message_uim_verify_pin_input_new ();
         if (!qmi_message_uim_verify_pin_input_set_info (
@@ -293,10 +300,10 @@ verify_pin_input_create (const gchar *str)
                 pin_id,
                 current_pin,
                 &error) ||
-            !qmi_message_uim_verify_pin_input_set_session_information (
+            !qmi_message_uim_verify_pin_input_set_session (
                 input,
                 QMI_UIM_SESSION_TYPE_CARD_SLOT_1,
-                "", /* ignored */
+                dummy_aid, /* ignored */
                 &error)) {
             g_printerr ("error: couldn't create input data bundle: '%s'\n",
                         error->message);
@@ -304,6 +311,7 @@ verify_pin_input_create (const gchar *str)
             qmi_message_uim_verify_pin_input_unref (input);
             input = NULL;
         }
+        g_array_unref (dummy_aid);
     }
     g_strfreev (split);
 
@@ -375,6 +383,9 @@ unblock_pin_input_create (const gchar *str)
         qmicli_read_non_empty_string (split[1], "PUK", &puk) &&
         qmicli_read_non_empty_string (split[2], "new PIN", &new_pin)) {
         GError *error = NULL;
+        GArray *dummy_aid;
+
+        dummy_aid = g_array_new (FALSE, FALSE, sizeof (guint8));
 
         input = qmi_message_uim_unblock_pin_input_new ();
         if (!qmi_message_uim_unblock_pin_input_set_info (
@@ -383,10 +394,10 @@ unblock_pin_input_create (const gchar *str)
                 puk,
                 new_pin,
                 &error) ||
-            !qmi_message_uim_unblock_pin_input_set_session_information (
+            !qmi_message_uim_unblock_pin_input_set_session (
                 input,
                 QMI_UIM_SESSION_TYPE_CARD_SLOT_1,
-                "", /* ignored */
+                dummy_aid, /* ignored */
                 &error)) {
             g_printerr ("error: couldn't create input data bundle: '%s'\n",
                         error->message);
@@ -394,6 +405,7 @@ unblock_pin_input_create (const gchar *str)
             qmi_message_uim_unblock_pin_input_unref (input);
             input = NULL;
         }
+        g_array_unref (dummy_aid);
     }
     g_strfreev (split);
 
@@ -465,6 +477,9 @@ change_pin_input_create (const gchar *str)
         qmicli_read_non_empty_string (split[1], "old PIN", &old_pin) &&
         qmicli_read_non_empty_string (split[2], "new PIN", &new_pin)) {
         GError *error = NULL;
+        GArray *dummy_aid;
+
+        dummy_aid = g_array_new (FALSE, FALSE, sizeof (guint8));
 
         input = qmi_message_uim_change_pin_input_new ();
         if (!qmi_message_uim_change_pin_input_set_info (
@@ -473,10 +488,10 @@ change_pin_input_create (const gchar *str)
                 old_pin,
                 new_pin,
                 &error) ||
-            !qmi_message_uim_change_pin_input_set_session_information (
+            !qmi_message_uim_change_pin_input_set_session (
                 input,
                 QMI_UIM_SESSION_TYPE_CARD_SLOT_1,
-                "", /* ignored */
+                dummy_aid, /* ignored */
                 &error)) {
             g_printerr ("error: couldn't create input data bundle: '%s'\n",
                         error->message);
@@ -484,6 +499,7 @@ change_pin_input_create (const gchar *str)
             qmi_message_uim_change_pin_input_unref (input);
             input = NULL;
         }
+        g_array_unref (dummy_aid);
     }
     g_strfreev (split);
 
@@ -769,29 +785,29 @@ get_card_status_ready (QmiClientUim *client,
         g_print ("\tPrimary GW:   session doesn't exist\n");
     else
         g_print ("\tPrimary GW:   slot '%u', application '%u'\n",
-                 ((index_gw_primary & 0xFF00) >> 8),
-                 ((index_gw_primary & 0x00FF)));
+                 ((index_gw_primary & 0xFF00) >> 8) + 1,
+                 ((index_gw_primary & 0x00FF)) + 1);
 
     if (index_1x_primary == 0xFFFF)
         g_print ("\tPrimary 1X:   session doesn't exist\n");
     else
         g_print ("\tPrimary 1X:   slot '%u', application '%u'\n",
-                 ((index_1x_primary & 0xFF00) >> 8),
-                 ((index_1x_primary & 0x00FF)));
+                 ((index_1x_primary & 0xFF00) >> 8) + 1,
+                 ((index_1x_primary & 0x00FF)) + 1);
 
     if (index_gw_secondary == 0xFFFF)
         g_print ("\tSecondary GW: session doesn't exist\n");
     else
         g_print ("\tSecondary GW: slot '%u', application '%u'\n",
-                 ((index_gw_secondary & 0xFF00) >> 8),
-                 ((index_gw_secondary & 0x00FF)));
+                 ((index_gw_secondary & 0xFF00) >> 8) + 1,
+                 ((index_gw_secondary & 0x00FF)) + 1);
 
     if (index_1x_secondary == 0xFFFF)
         g_print ("\tSecondary 1X: session doesn't exist\n");
     else
         g_print ("\tSecondary 1X: slot '%u', application '%u'\n",
-                 ((index_1x_secondary & 0xFF00) >> 8),
-                 ((index_1x_secondary & 0x00FF)));
+                 ((index_1x_secondary & 0xFF00) >> 8) + 1,
+                 ((index_1x_secondary & 0x00FF)) + 1);
 
     for (i = 0; i < cards->len; i++) {
         QmiMessageUimGetCardStatusOutputCardStatusCardsElement *card;
@@ -799,7 +815,7 @@ get_card_status_ready (QmiClientUim *client,
 
         card = &g_array_index (cards, QmiMessageUimGetCardStatusOutputCardStatusCardsElement, i);
 
-        g_print ("Card [%u]:\n", i);
+        g_print ("Slot [%u]:\n", i + 1);
 
         if (card->card_state != QMI_UIM_CARD_STATE_ERROR)
             g_print ("\tCard state: '%s'\n",
@@ -829,7 +845,7 @@ get_card_status_ready (QmiClientUim *client,
                      "\t\tApplication state: '%s'\n"
                      "\t\tApplication ID:\n"
                      "\t\t\t%s",
-                     j,
+                     j + 1,
                      VALIDATE_UNKNOWN (qmi_uim_card_application_type_get_string (app->type)), app->type,
                      qmi_uim_card_application_state_get_string (app->state),
                      str);
@@ -1007,15 +1023,18 @@ read_transparent_build_input (const gchar *file_path_str)
     QmiMessageUimReadTransparentInput *input;
     guint16 file_id = 0;
     GArray *file_path = NULL;
+    GArray *dummy_aid;
 
     if (!get_sim_file_id_and_path (file_path_str, &file_id, &file_path))
         return NULL;
 
+    dummy_aid = g_array_new (FALSE, FALSE, sizeof (guint8));
+
     input = qmi_message_uim_read_transparent_input_new ();
-    qmi_message_uim_read_transparent_input_set_session_information (
+    qmi_message_uim_read_transparent_input_set_session (
         input,
         QMI_UIM_SESSION_TYPE_PRIMARY_GW_PROVISIONING,
-        "",
+        dummy_aid, /* ignored */
         NULL);
     qmi_message_uim_read_transparent_input_set_file (
         input,
@@ -1024,6 +1043,7 @@ read_transparent_build_input (const gchar *file_path_str)
         NULL);
     qmi_message_uim_read_transparent_input_set_read_information (input, 0, 0, NULL);
     g_array_unref (file_path);
+    g_array_unref (dummy_aid);
     return input;
 }
 
@@ -1157,6 +1177,7 @@ read_record_input_create (const gchar *str)
     };
     guint16 file_id = 0;
     GArray *file_path = NULL;
+    GArray *dummy_aid;
 
     if (!qmicli_parse_key_value_string (str,
                                         &error,
@@ -1172,12 +1193,14 @@ read_record_input_create (const gchar *str)
     if (!get_sim_file_id_and_path_with_separator (props.file, &file_id, &file_path, "-"))
         goto out;
 
+    dummy_aid = g_array_new (FALSE, FALSE, sizeof (guint8));
+
     input = qmi_message_uim_read_record_input_new ();
 
-    qmi_message_uim_read_record_input_set_session_information (
+    qmi_message_uim_read_record_input_set_session (
         input,
         QMI_UIM_SESSION_TYPE_PRIMARY_GW_PROVISIONING,
-        "",
+        dummy_aid, /* ignored */
         NULL);
     qmi_message_uim_read_record_input_set_file (
         input,
@@ -1190,6 +1213,8 @@ read_record_input_create (const gchar *str)
         props.record_length,
         NULL);
 
+    g_array_unref (dummy_aid);
+
 out:
     free (props.file);
     g_array_unref (file_path);
@@ -1345,21 +1370,25 @@ get_file_attributes_build_input (const gchar *file_path_str)
     QmiMessageUimGetFileAttributesInput *input;
     guint16 file_id = 0;
     GArray *file_path = NULL;
+    GArray *dummy_aid;
 
     if (!get_sim_file_id_and_path (file_path_str, &file_id, &file_path))
         return NULL;
 
+    dummy_aid = g_array_new (FALSE, FALSE, sizeof (guint8));
+
     input = qmi_message_uim_get_file_attributes_input_new ();
-    qmi_message_uim_get_file_attributes_input_set_session_information (
+    qmi_message_uim_get_file_attributes_input_set_session (
         input,
         QMI_UIM_SESSION_TYPE_PRIMARY_GW_PROVISIONING,
-        "",
+        dummy_aid, /* ignored */
         NULL);
     qmi_message_uim_get_file_attributes_input_set_file (
         input,
         file_id,
         file_path,
         NULL);
+    g_array_unref (dummy_aid);
     g_array_unref (file_path);
     return input;
 }
@@ -1562,6 +1591,7 @@ qmicli_uim_run (QmiDevice *device,
                                      ctx->cancellable,
                                      (GAsyncReadyCallback)power_on_sim_ready,
                                      NULL);
+        qmi_message_uim_power_on_sim_input_unref (input);
         return;
     }
 
@@ -1582,6 +1612,7 @@ qmicli_uim_run (QmiDevice *device,
                                       ctx->cancellable,
                                       (GAsyncReadyCallback)power_off_sim_ready,
                                       NULL);
+        qmi_message_uim_power_off_sim_input_unref (input);
         return;
     }
 
