@@ -49,6 +49,7 @@ static QmiDevice *device;
 static QmiClient *client;
 static QmiService service;
 static gboolean operation_status;
+static gboolean expect_indications;
 
 /* Main options */
 static gchar *device_str;
@@ -225,7 +226,7 @@ print_version_and_exit (void)
 {
     g_print ("\n"
              PROGRAM_NAME " " PROGRAM_VERSION "\n"
-             "Copyright (C) 2012-2018 Aleksander Morgado\n"
+             "Copyright (C) 2012-2019 Aleksander Morgado\n"
              "License GPLv2+: GNU GPL version 2 or later <http://gnu.org/licenses/gpl-2.0.html>\n"
              "This is free software: you are free to change and redistribute it.\n"
              "There is NO WARRANTY, to the extent permitted by law.\n"
@@ -257,6 +258,15 @@ generic_options_enabled (void)
     return !!n_actions;
 }
 
+/*****************************************************************************/
+/* Report that indications are expected */
+
+void
+qmicli_expect_indications (void)
+{
+    expect_indications = TRUE;
+}
+
 /*****************************************************************************/
 /* Running asynchronously */
 
@@ -372,6 +382,12 @@ allocate_client_ready (QmiDevice *dev,
     case QMI_SERVICE_VOICE:
         qmicli_voice_run (dev, QMI_CLIENT_VOICE (client), cancellable);
         return;
+    case QMI_SERVICE_LOC:
+        qmicli_loc_run (dev, QMI_CLIENT_LOC (client), cancellable);
+        return;
+    case QMI_SERVICE_QOS:
+        qmicli_qos_run (dev, QMI_CLIENT_QOS (client), cancellable);
+        return;
     default:
         g_assert_not_reached ();
     }
@@ -651,6 +667,8 @@ device_new_ready (GObject *unused,
         open_flags |= QMI_DEVICE_OPEN_FLAGS_MBIM;
     if (device_open_auto_flag || (!device_open_qmi_flag && !device_open_mbim_flag))
         open_flags |= QMI_DEVICE_OPEN_FLAGS_AUTO;
+    if (expect_indications)
+        open_flags |= QMI_DEVICE_OPEN_FLAGS_EXPECT_INDICATIONS;
     if (device_open_net_str)
         if (!qmicli_read_net_open_flags_from_string (device_open_net_str, &open_flags))
             exit (EXIT_FAILURE);
@@ -731,6 +749,18 @@ parse_actions (void)
         actions_enabled++;
     }
 
+    /* LOC options? */
+    if (qmicli_loc_options_enabled ()) {
+        service = QMI_SERVICE_LOC;
+        actions_enabled++;
+    }
+
+    /* QOS options? */
+    if (qmicli_qos_options_enabled ()) {
+        service = QMI_SERVICE_QOS;
+        actions_enabled++;
+    }
+
     /* Cannot mix actions from different services */
     if (actions_enabled > 1) {
         g_printerr ("error: cannot execute multiple actions of different services\n");
@@ -774,6 +804,10 @@ int main (int argc, char **argv)
                                 qmicli_wda_get_option_group ());
     g_option_context_add_group (context,
                                 qmicli_voice_get_option_group ());
+    g_option_context_add_group (context,
+                                qmicli_loc_get_option_group ());
+    g_option_context_add_group (context,
+                                qmicli_qos_get_option_group ());
     g_option_context_add_main_entries (context, main_entries, NULL);
     if (!g_option_context_parse (context, &argc, &argv, &error)) {
         g_printerr ("error: %s\n",
